@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -11,6 +14,7 @@ import typing_extensions
 from typeguard import check_type
 
 import aws_cdk._jsii
+import aws_cdk.integ_tests_alpha._jsii
 import aws_solutions_constructs.aws_iot_lambda._jsii
 import aws_solutions_constructs.aws_lambda_dynamodb._jsii
 import aws_solutions_constructs.core._jsii
@@ -18,9 +22,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-iot-lambda-dynamodb",
-    "2.44.0",
+    "2.59.0",
     __name__[0:-6],
-    "aws-iot-lambda-dynamodb@2.44.0.jsii.tgz",
+    "aws-iot-lambda-dynamodb@2.59.0.jsii.tgz",
 )
 
 __all__ = [
